require_relative '../test_helper'

class PackageTest < Minitest::Test
  def setup
    init_environment
    @api_key = ENV["VEYE_API_KEY"]
  end

  def test_info_api_call
    VCR.use_cassette('package_info') do
      res = Veye::API::Package::get_package(@api_key, 'veye', 'ruby')

      assert_equal 200, res.code
      assert_equal true, res.success
      assert_equal "veye", res.data["name"]
      assert_equal "ruby", res.data["language"]
      assert_equal "veye", res.data["prod_key"]
    end
  end

  def test_search_api_call
    VCR.use_cassette('package_search') do
      res = Veye::API::Package.search(@api_key, 'veye')
      refute_nil res
      assert_equal true, res.success
      assert_equal 200, res.code
      refute_nil res.data["results"], "Search results are empty"
      dt = res.data["results"].first
      assert_equal "veye", dt["name"]
      assert_equal "ruby", dt["language"]
      assert_equal "veye", dt["prod_key"]
      assert_equal "RubyGem", dt["prod_type"]
    end
  end

  def test_version_list_api_call
    VCR.use_cassette('package_versions') do
      res = Veye::API::Package.get_version_list(@api_key, 'ruby', 'ruby')
      refute_nil res
      assert_equal 200, res.code
      assert_equal true, res.success
      assert_equal 'ruby', res.data['name']
      assert_equal 'ruby', res.data['language']
      assert_equal '0.1.0', res.data['version']
      assert_equal 'RubyGem', res.data['prod_type']
      assert_equal 1, res.data['versions'].count
      assert_equal '0.1.0', res.data['versions'].first['version']
    end
  end

  def test_get_follow_status_api_call
    VCR.use_cassette('package_follow_status') do
      res = Veye::API::Package.get_follow_status(@api_key, 'ruby', 'ruby')
      refute_nil res
      assert_equal 200, res.code
      assert_equal true, res.success
      assert_equal "ruby", res.data["prod_key"]
      assert_equal false, res.data["follows"]
    end
  end

  def test_follow_api_call
    VCR.use_cassette('package_follow') do
      res = Veye::API::Package.follow(@api_key, 'ruby', 'ruby')
      refute_nil res
      assert_equal 201, res.code
      assert_equal true, res.success
      assert_equal "ruby", res.data["prod_key"]
      assert_equal true, res.data["follows"]
    end
  end

  def test_unfollow_api_call
    VCR.use_cassette('package_unfollow') do
      res = Veye::API::Package.unfollow(@api_key, 'ruby', 'ruby')
      refute_nil res
      assert_equal 200, res.code
      assert_equal true, res.success
      assert_equal "ruby", res.data["prod_key"]
      assert_equal false, res.data["follows"]
    end
  end

  def test_reference_api_call
    VCR.use_cassette('package_reference') do
      res = Veye::API::Package.get_references(@api_key, 'ruby', 'ruby')
      refute_nil res

      assert_equal 200, res.code
      assert_equal true, res.success
      assert_equal "gitit", res.data['results'].first.fetch("name", nil)
    end
  end


end
